import { __values, __decorate, __metadata } from 'tslib';
import { moveItemInArray, DragDropModule } from '@angular/cdk/drag-drop';
import { Injectable, EventEmitter, Input, TemplateRef, Output, Component, ViewEncapsulation, ChangeDetectionStrategy, Pipe, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

var Constants = /** @class */ (function () {
    function Constants() {
    }
    Constants.filters = function () {
        return [{
                name: FilterTypes.StartsWith,
                text: "abc*",
                forDataType: DataTypes.String
            },
            {
                name: FilterTypes.EndsWith,
                text: "*abc",
                forDataType: DataTypes.String
            },
            {
                name: FilterTypes.Contains,
                text: "*abc*",
                forDataType: DataTypes.String
            },
            {
                name: FilterTypes.GreaterThan,
                text: ">",
                forDataType: DataTypes.Number
            },
            {
                name: FilterTypes.LessThan,
                text: "<",
                forDataType: DataTypes.Number
            },
            {
                name: FilterTypes.GreaterThanOrEquals,
                text: ">=",
                forDataType: DataTypes.Number
            },
            {
                name: FilterTypes.LessThanOrEquals,
                text: "<=",
                forDataType: DataTypes.Number
            }, {
                name: FilterTypes.Equals,
                text: "=",
                forDataType: DataTypes.Number
            },
            {
                name: FilterTypes.Equals,
                text: "=",
                forDataType: DataTypes.Boolean
            },
            {
                name: FilterTypes.GreaterThan,
                text: ">",
                forDataType: DataTypes.Date
            }, {
                name: FilterTypes.LessThan,
                text: "<",
                forDataType: DataTypes.Date
            },
            {
                name: FilterTypes.GreaterThanOrEquals,
                text: ">=",
                forDataType: DataTypes.Date
            }, {
                name: FilterTypes.LessThanOrEquals,
                text: "<=",
                forDataType: DataTypes.Date
            }, {
                name: FilterTypes.Equals,
                text: "=",
                forDataType: DataTypes.Date
            }, {
                name: FilterTypes.NotEquals,
                text: "≠",
                forDataType: DataTypes.Number
            },
            {
                name: FilterTypes.NotEquals,
                text: "≠",
                forDataType: DataTypes.Date
            },
            {
                name: FilterTypes.NotEquals,
                text: "≠",
                forDataType: DataTypes.Boolean
            }];
    };
    return Constants;
}());
var FilterTypes;
(function (FilterTypes) {
    FilterTypes["StartsWith"] = "startswith";
    FilterTypes["EndsWith"] = "endswith";
    FilterTypes["Contains"] = "contains";
    FilterTypes["GreaterThan"] = "gt";
    FilterTypes["LessThan"] = "lt";
    FilterTypes["LessThanOrEquals"] = "le";
    FilterTypes["GreaterThanOrEquals"] = "ge";
    FilterTypes["Equals"] = "eq";
    FilterTypes["NotEquals"] = "ne";
    FilterTypes["Reset"] = "Reset";
})(FilterTypes || (FilterTypes = {}));
var DataTypes;
(function (DataTypes) {
    DataTypes["Number"] = "number";
    DataTypes["String"] = "string";
    DataTypes["Date"] = "date";
    DataTypes["Boolean"] = "boolean";
})(DataTypes || (DataTypes = {}));
var SortDirections;
(function (SortDirections) {
    SortDirections["Ascending"] = "asc";
    SortDirections["Descending"] = "desc";
})(SortDirections || (SortDirections = {}));

/**
 * grid column class
 */
var Column = /** @class */ (function () {
    /**constructor */
    function Column(item) {
        this.dataField = item["dataField"];
        this.dataType = item["dataType"] ? item["dataType"] : DataTypes.String;
        this.visible = item["visible"];
        this.width = item["width"];
        this.caption = item["caption"] ? item["caption"] : item["dataField"];
        this.sortDirection = item["sortDirection"];
        this.filterValue = item["filterValue"];
        this.filterOperator = item["filterOperator"];
        this.sortEnable = item["sortEnable"];
        this.filterEnable = item["filterEnable"];
        this.cellTemplate = item["cellTemplate"];
        this.onCellClick = item["onCellClick"];
        this.styleClass = item["styleClass"];
        this.rightAlignText = item["rightAlignText"];
        this.stickyColumnLeft = item["stickyColumnLeft"];
        this.stickyColumnRight = item["stickyColumnRight"];
    }
    return Column;
}());

var DataSource = /** @class */ (function () {
    function DataSource(data, total, summary, isAllPages) {
        this.data = data;
        this.total = total;
        this.summary = summary;
        this.isAllPages = isAllPages ? isAllPages : false;
    }
    return DataSource;
}());

var LoadOptions = /** @class */ (function () {
    function LoadOptions() {
    }
    return LoadOptions;
}());

var State = /** @class */ (function () {
    function State(name, columns) {
        this.name = name;
        this.columns = columns;
    }
    return State;
}());

var NpFileService = /** @class */ (function () {
    function NpFileService() {
    }
    NpFileService.prototype.downloadCSVFile = function (data, columns, fileName) {
        var CSVData = this.createCSVData(data, columns);
        return this.downloadFile(CSVData, this.normalizeFileName(fileName, 'csv'));
    };
    NpFileService.prototype.downloadFile = function (content, fileName) {
        var dataURI = this.generateDataURI(content);
        var anchor = document.createElement('a');
        anchor.href = dataURI;
        anchor.download = fileName;
        anchor.setAttribute('style', 'visibility:hidden');
        document.body.appendChild(anchor);
        anchor.click();
        document.body.removeChild(anchor);
    };
    NpFileService.prototype.generateDataURI = function (content) {
        return 'data:text/csv;charset=utf-8,\uFEFF' + encodeURIComponent(content);
    };
    NpFileService.prototype.createCSVData = function (data, columnList) {
        var e_1, _a, e_2, _b, e_3, _c;
        var headersLabels = [];
        var headers = [];
        try {
            for (var columnList_1 = __values(columnList), columnList_1_1 = columnList_1.next(); !columnList_1_1.done; columnList_1_1 = columnList_1.next()) {
                var element = columnList_1_1.value;
                if (element.dataField === undefined) {
                    continue;
                }
                headersLabels.push(element.caption);
                headers.push(element.dataField);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (columnList_1_1 && !columnList_1_1.done && (_a = columnList_1.return)) _a.call(columnList_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        var head = headersLabels.join(',') + '\r\n';
        var rows = [];
        try {
            for (var data_1 = __values(data), data_1_1 = data_1.next(); !data_1_1.done; data_1_1 = data_1.next()) {
                var element = data_1_1.value;
                var cols = [];
                try {
                    for (var headers_1 = (e_3 = void 0, __values(headers)), headers_1_1 = headers_1.next(); !headers_1_1.done; headers_1_1 = headers_1.next()) {
                        var column = headers_1_1.value;
                        cols.push("\"" + element[column].toString().replace(/\"/g, '""') + "\"");
                    }
                }
                catch (e_3_1) { e_3 = { error: e_3_1 }; }
                finally {
                    try {
                        if (headers_1_1 && !headers_1_1.done && (_c = headers_1.return)) _c.call(headers_1);
                    }
                    finally { if (e_3) throw e_3.error; }
                }
                rows.push(cols.join(","));
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (data_1_1 && !data_1_1.done && (_b = data_1.return)) _b.call(data_1);
            }
            finally { if (e_2) throw e_2.error; }
        }
        return head + rows.join('\r\n');
    };
    NpFileService.prototype.normalizeFileName = function (fileName, extension) {
        if (fileName === undefined || fileName === null || fileName.length === 0) {
            fileName = "download";
        }
        var suffix = '.' + extension;
        var extensionPattern = new RegExp("(\\" + extension + ")?$");
        return fileName.replace(/\s+/, '_').replace(extensionPattern, suffix);
    };
    NpFileService = __decorate([
        Injectable()
    ], NpFileService);
    return NpFileService;
}());

var NpFilterService = /** @class */ (function () {
    function NpFilterService() {
    }
    NpFilterService.prototype.filterData = function (filterColumns, data) {
        var e_1, _a;
        var _loop_1 = function (element) {
            if (element.filterOperator === FilterTypes.StartsWith) {
                data = this_1._custFilter(data, function (a) {
                    return a[element.dataField].toLowerCase().startsWith(element.filterValue.toLowerCase(), 0);
                });
            }
            else if (element.filterOperator === FilterTypes.EndsWith) {
                data = this_1._custFilter(data, function (a) {
                    return a[element.dataField].toLowerCase().endsWith(element.filterValue.toLowerCase());
                });
            }
            else if (element.filterOperator === FilterTypes.Contains) {
                data = this_1._custFilter(data, function (a) {
                    return a[element.dataField].toLowerCase().indexOf(element.filterValue.toLowerCase()) !== -1;
                });
            }
            else if (element.filterOperator === FilterTypes.GreaterThan) {
                if (element.dataType === DataTypes.Number) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField] > parseInt(element.filterValue);
                    });
                }
                else if (element.dataType === DataTypes.Date) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField].setHours(0, 0, 0, 0) > new Date(element.filterValue).setHours(0, 0, 0, 0);
                    });
                }
            }
            else if (element.filterOperator === FilterTypes.GreaterThanOrEquals) {
                if (element.dataType === DataTypes.Number) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField] >= parseInt(element.filterValue);
                    });
                }
                else if (element.dataType === DataTypes.Date) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField].setHours(0, 0, 0, 0) >= new Date(element.filterValue).setHours(0, 0, 0, 0);
                    });
                }
            }
            else if (element.filterOperator === FilterTypes.LessThan) {
                if (element.dataType === DataTypes.Number) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField] < parseInt(element.filterValue);
                    });
                }
                else if (element.dataType === DataTypes.Date) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField].setHours(0, 0, 0, 0) < new Date(element.filterValue).setHours(0, 0, 0, 0);
                    });
                }
            }
            else if (element.filterOperator === FilterTypes.LessThanOrEquals) {
                if (element.dataType === DataTypes.Number) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField] <= parseInt(element.filterValue);
                    });
                }
                else if (element.dataType === DataTypes.Date) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField].setHours(0, 0, 0, 0) <= new Date(element.filterValue).setHours(0, 0, 0, 0);
                    });
                }
            }
            else if (element.filterOperator === FilterTypes.Equals) {
                if (element.dataType === DataTypes.Boolean) {
                    if (element.filterValue === "true") {
                        data = this_1._custFilter(data, function (a) {
                            return a[element.dataField] === true;
                        });
                    }
                    else {
                        data = this_1._custFilter(data, function (a) {
                            return a[element.dataField] === false;
                        });
                    }
                }
                else if (element.dataType === DataTypes.Number) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField] === parseInt(element.filterValue);
                    });
                }
                else if (element.dataType === DataTypes.Date) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField].setHours(0, 0, 0, 0) === new Date(element.filterValue).setHours(0, 0, 0, 0);
                    });
                }
            }
            else if (element.filterOperator === FilterTypes.NotEquals) {
                if (element.dataType === DataTypes.Boolean) {
                    if (element.filterValue === "true") {
                        data = this_1._custFilter(data, function (a) {
                            return a[element.dataField] !== true;
                        });
                    }
                    else {
                        data = this_1._custFilter(data, function (a) {
                            return a[element.dataField] !== false;
                        });
                    }
                }
                else if (element.dataType === DataTypes.Number) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField] !== parseInt(element.filterValue);
                    });
                }
                else if (element.dataType === DataTypes.Date) {
                    data = this_1._custFilter(data, function (a) {
                        return a[element.dataField].setHours(0, 0, 0, 0) !== new Date(element.filterValue).setHours(0, 0, 0, 0);
                    });
                }
            }
        };
        var this_1 = this;
        try {
            for (var filterColumns_1 = __values(filterColumns), filterColumns_1_1 = filterColumns_1.next(); !filterColumns_1_1.done; filterColumns_1_1 = filterColumns_1.next()) {
                var element = filterColumns_1_1.value;
                _loop_1(element);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (filterColumns_1_1 && !filterColumns_1_1.done && (_a = filterColumns_1.return)) _a.call(filterColumns_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return data;
    };
    NpFilterService.prototype._custFilter = function (arr, fun) {
        return arr.filter(fun);
    };
    NpFilterService = __decorate([
        Injectable()
    ], NpFilterService);
    return NpFilterService;
}());

var NpODataService = /** @class */ (function () {
    function NpODataService() {
    }
    NpODataService.prototype.buildQuery = function (top, skip, sortColumns, filterColumns, inlineCount) {
        var e_1, _a, e_2, _b;
        var queryTmpArray = [];
        if (inlineCount && inlineCount.length > 0) {
            queryTmpArray.push("$inlinecount=" + inlineCount);
        }
        else {
            queryTmpArray.push('$count=true');
            queryTmpArray.push("$top=" + top);
            queryTmpArray.push("$skip=" + skip);
        }
        if (sortColumns) {
            var sortQueue = [];
            try {
                for (var sortColumns_1 = __values(sortColumns), sortColumns_1_1 = sortColumns_1.next(); !sortColumns_1_1.done; sortColumns_1_1 = sortColumns_1.next()) {
                    var element = sortColumns_1_1.value;
                    sortQueue.push(element.dataField + " " + element.sortDirection);
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (sortColumns_1_1 && !sortColumns_1_1.done && (_a = sortColumns_1.return)) _a.call(sortColumns_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            if (sortQueue.length > 0) {
                queryTmpArray.push("$orderby=" + sortQueue.join(','));
            }
        }
        if (filterColumns) {
            if (filterColumns && filterColumns.length === 1) {
                if (filterColumns[0].dataType === DataTypes.String) {
                    queryTmpArray.push("$filter=" + filterColumns[0].filterOperator + "(" + filterColumns[0].dataField + ",'" + filterColumns[0].filterValue + "')");
                }
                else {
                    queryTmpArray.push("$filter=" + filterColumns[0].dataField + " " + filterColumns[0].filterOperator + " " + filterColumns[0].filterValue);
                }
            }
            if (filterColumns && filterColumns.length > 1) {
                var filterQueue = [];
                try {
                    for (var filterColumns_1 = __values(filterColumns), filterColumns_1_1 = filterColumns_1.next(); !filterColumns_1_1.done; filterColumns_1_1 = filterColumns_1.next()) {
                        var element = filterColumns_1_1.value;
                        if (element.dataType === DataTypes.String) {
                            filterQueue.push(element.filterOperator + "(" + element.dataField + ",'" + element.filterValue + "')");
                        }
                        else {
                            filterQueue.push(element.dataField + " " + element.filterOperator + " " + element.filterValue);
                        }
                    }
                }
                catch (e_2_1) { e_2 = { error: e_2_1 }; }
                finally {
                    try {
                        if (filterColumns_1_1 && !filterColumns_1_1.done && (_b = filterColumns_1.return)) _b.call(filterColumns_1);
                    }
                    finally { if (e_2) throw e_2.error; }
                }
                if (filterQueue.length > 1) {
                    queryTmpArray.push("$filter=" + filterQueue.join(' and '));
                }
            }
        }
        return queryTmpArray.join('&');
    };
    NpODataService = __decorate([
        Injectable()
    ], NpODataService);
    return NpODataService;
}());

var NpPagerService = /** @class */ (function () {
    function NpPagerService() {
    }
    NpPagerService.prototype.getPager = function (totalItems, currentPage, pageSize) {
        if (currentPage === void 0) { currentPage = 1; }
        if (pageSize === void 0) { pageSize = 10; }
        // calculate total pages
        pageSize = parseInt(pageSize.toString());
        var totalPages = Math.ceil(totalItems / pageSize);
        // ensure current page isn't out of range
        if (currentPage < 1) {
            currentPage = 1;
        }
        else if (currentPage > totalPages) {
            currentPage = totalPages;
        }
        var startPage, endPage;
        if (totalPages <= 10) {
            // less than 10 total pages so show all
            startPage = 1;
            endPage = totalPages;
        }
        else {
            // more than 10 total pages so calculate start and end pages
            if (currentPage <= 6) {
                startPage = 1;
                endPage = 10;
            }
            else if (currentPage + 4 >= totalPages) {
                startPage = totalPages - 9;
                endPage = totalPages;
            }
            else {
                startPage = currentPage - 5;
                endPage = currentPage + 4;
            }
        }
        // calculate start and end item indexes
        var startIndex = (currentPage - 1) * pageSize;
        var endIndex = Math.min(startIndex + pageSize - 1, totalItems - 1);
        // create an array of pages to ng-repeat in the pager control
        var pages = Array.from(Array((endPage + 1) - startPage).keys()).map(function (i) { return startPage + i; });
        // return object with all pager properties required by the view
        return {
            totalItems: totalItems,
            currentPage: currentPage,
            pageSize: pageSize,
            totalPages: totalPages,
            startPage: startPage,
            endPage: endPage,
            startIndex: startIndex,
            endIndex: endIndex,
            pages: pages
        };
    };
    NpPagerService = __decorate([
        Injectable()
    ], NpPagerService);
    return NpPagerService;
}());

var NpUtilityService = /** @class */ (function () {
    function NpUtilityService() {
    }
    NpUtilityService.prototype.custFilter = function (arr, fun) {
        return arr.filter(fun);
    };
    NpUtilityService.prototype.custFind = function (arr, fun) {
        return arr.find(fun);
    };
    NpUtilityService.prototype.custSort = function (arr, ele, order) {
        if (order === SortDirections.Ascending) {
            return arr.concat().sort(function (a, b) { return (a[ele] > b[ele]) ? 1 : ((b[ele] > a[ele]) ? -1 : 0); });
        }
        else {
            return arr.concat().sort(function (a, b) { return (a[ele] < b[ele]) ? 1 : ((b[ele] < a[ele]) ? -1 : 0); });
        }
    };
    NpUtilityService = __decorate([
        Injectable()
    ], NpUtilityService);
    return NpUtilityService;
}());

var NpUiDataGridComponent = /** @class */ (function () {
    function NpUiDataGridComponent(pagerService, filterService, utilityService, oDataService, fileService) {
        this.pagerService = pagerService;
        this.filterService = filterService;
        this.utilityService = utilityService;
        this.oDataService = oDataService;
        this.fileService = fileService;
        this._total = 0;
        this._enableMasterChild = false;
        this.singleRowExpand = false;
        this.expandRowOnClick = false;
        this._openRowKeys = [];
        this.stickyHeader = false;
        this._showLoader = false;
        this.singleRowSelectEnable = false;
        this.multiRowSelectEnable = false;
        this.selectRowOnClick = false;
        this._selectedRowKeys = [];
        this.onSelect = new EventEmitter();
        this.onDeselect = new EventEmitter();
        this.onRowClick = new EventEmitter();
        this._dataTypes = DataTypes;
        this._sortDirections = SortDirections;
        this._isOpenColumnChooser = false;
        this._visibleColumns = [];
        this.title = "";
        this.onStatesUpdate = new EventEmitter();
        this.noDataMessage = "No Data Found.";
        this.showFilters = true;
        this.onInit = new EventEmitter();
        this.onAfterInit = new EventEmitter();
        this.showSummary = false;
        this.allowColumnResize = false;
        this.allowColumnReorder = false;
        this.onLoadData = new EventEmitter();
        this.isServerOperations = false;
        this.isODataOperations = false;
        this.allowExportToCSV = false;
        this.showToolBar = false;
        this.pageSize = 10;
        this._sortColumnList = [];
        this._filtersList = Constants.filters();
        this._filterColumnList = [];
        this._stateList = [];
        this._currentStateName = "";
        this._isFilterAvailable = false;
        this.showFilters = true;
        this._tableId = "tbl-" + Math.floor(Math.random() * 6 + 1);
    }
    NpUiDataGridComponent.prototype.ngOnInit = function () {
        if (this.onInit != undefined) {
            this.onInit.emit();
        }
    };
    NpUiDataGridComponent.prototype.ngAfterViewInit = function () {
        if (this.onAfterInit != undefined) {
            this.onAfterInit.emit();
        }
    };
    NpUiDataGridComponent.prototype.ngOnChanges = function (changes) {
        if (changes.tableId) {
            this._tableId = this.tableId;
        }
        if (changes.columns) {
            this._setColumns();
            if (this._key === undefined) {
                this._key = this._columns[0].dataField;
            }
        }
        if (changes.dataSource) {
            this.subscribeDataSource();
        }
        if (changes.masterDetailTemplate) {
            this._enableMasterChild = true;
        }
        if (changes.key) {
            this._key = this.key;
        }
        if (changes.isServerOperations) {
            this._getCurrentViewData(1);
        }
    };
    NpUiDataGridComponent.prototype.subscribeDataSource = function () {
        var _this = this;
        this._subscription = this.dataSource.subscribe(function (data) {
            var e_1, _a;
            if (data === undefined || data === null) {
                return;
            }
            if (_this.isServerOperations) {
                // to export to csv, this change has all data
                if (data.isAllPages) {
                    _this.fileService.downloadCSVFile(data.data, _this._visibleColumns);
                    _this.hideLoader();
                    return;
                }
                _this._currentViewData = data.data;
                _this._summaryData = data.summary;
                _this._total = data.total;
                if (_this._isAllSelected) {
                    try {
                        for (var _b = __values(_this._currentViewData), _c = _b.next(); !_c.done; _c = _b.next()) {
                            var element = _c.value;
                            if (_this._selectedRowKeys.indexOf(element[_this._key]) === -1) {
                                _this._selectedRowKeys.push(element[_this._key]);
                            }
                        }
                    }
                    catch (e_1_1) { e_1 = { error: e_1_1 }; }
                    finally {
                        try {
                            if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                        }
                        finally { if (e_1) throw e_1.error; }
                    }
                }
                _this._pager = _this.pagerService.getPager(_this._total, _this._pager.currentPage, _this.pageSize);
                _this._showLoader = false;
            }
            else {
                var dataSource = new DataSource(data.data, data.data.length, data.summary);
                _this._dataSource = dataSource;
                _this._total = _this._dataSource.total;
                _this._summaryData = _this._dataSource.summary;
                _this._getCurrentViewData(1);
            }
        });
    };
    NpUiDataGridComponent.prototype.ngOnDestroy = function () {
        if (this._subscription) {
            this._subscription.unsubscribe();
        }
    };
    NpUiDataGridComponent.prototype._getCurrentViewData = function (currentPageNumber) {
        if (currentPageNumber === 0) {
            currentPageNumber = 1;
        }
        if (this._pager && this._pager.totalPages > 0 && currentPageNumber > this._pager.totalPages) {
            currentPageNumber = this._pager.totalPages;
        }
        this._pager = this.pagerService.getPager(this._total, currentPageNumber, this.pageSize);
        if (this.isServerOperations) {
            this._showLoader = true;
            var loadOpt = new LoadOptions();
            if (this.isODataOperations) {
                var top = this.pageSize;
                var skip = (currentPageNumber - 1) * this.pageSize;
                loadOpt.odataQuery = this.oDataService.buildQuery(top, skip, this._sortColumnList, this._filterColumnList);
                loadOpt.pageNumber = 0;
                loadOpt.pageSize = 0;
                loadOpt.sortColumns = [];
                loadOpt.filterColumns = [];
                loadOpt.isAllPages = false;
            }
            else {
                loadOpt.pageNumber = currentPageNumber;
                loadOpt.pageSize = this.pageSize;
                loadOpt.sortColumns = this._sortColumnList;
                loadOpt.filterColumns = this._filterColumnList;
                loadOpt.isAllPages = false;
                loadOpt.odataQuery = "";
            }
            this.onLoadData.emit(loadOpt);
        }
        else {
            this._currentViewData = this._dataSource.data.slice(this._pager.startIndex, this._pager.endIndex + 1);
        }
    };
    NpUiDataGridComponent.prototype._setColumns = function () {
        var e_2, _a;
        var result = [];
        try {
            for (var _b = __values(this.columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                result.push(new Column(element));
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_2) throw e_2.error; }
        }
        this._columns = result;
        this._setVisibleColumns();
    };
    NpUiDataGridComponent.prototype._setVisibleColumns = function () {
        this._visibleColumns = this.utilityService.custFilter(this._columns, function (element) { if (element.visible === true) {
            return element;
        } });
        this._isFilterAvailable = this.utilityService.custFilter(this._columns, function (element) { if (element.filterEnable === true && element.visible === true) {
            return element;
        } }).length > 0;
    };
    NpUiDataGridComponent.prototype._onPageSizeChange = function () {
        this._getCurrentViewData(1);
    };
    NpUiDataGridComponent.prototype._onCellClick = function ($event, column, data) {
        if (column.onCellClick != undefined) {
            column.onCellClick($event, column, data);
        }
    };
    // on first click ascending, on second click descending and on third click remove sorting
    NpUiDataGridComponent.prototype._onSort = function (column) {
        var e_3, _a;
        if (!column.sortEnable) {
            return;
        }
        // if sort direction is descending then remove sorting from column
        if (column.sortDirection === SortDirections.Descending) {
            this._removeSortingFromColumn(column);
            return;
        }
        var sortOrder = column.sortDirection === SortDirections.Ascending ? SortDirections.Descending : SortDirections.Ascending;
        if (!this.multiColumnSortEnable) {
            this._removeAllSorting();
        }
        column.sortDirection = sortOrder;
        if (this.multiColumnSortEnable) {
            var list = [];
            try {
                for (var _b = __values(this._sortColumnList), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var element = _c.value;
                    if (element.dataField !== column.dataField) {
                        list.push(element);
                    }
                }
            }
            catch (e_3_1) { e_3 = { error: e_3_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_3) throw e_3.error; }
            }
            this._sortColumnList = list;
        }
        this._sortColumnList.push({ dataField: column.dataField, sortDirection: column.sortDirection });
        this._selectedRowKeys = [];
        this._isAllSelected = false;
        this._openRowKeys = [];
        if (!this.isServerOperations) {
            this._sortDataSource();
        }
        this._getCurrentViewData(1);
    };
    NpUiDataGridComponent.prototype._sortDataSource = function () {
        var e_4, _a;
        var data = this._dataSource.data;
        try {
            for (var _b = __values(this._sortColumnList), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                data = this.utilityService.custSort(data, element.dataField, element.sortDirection);
            }
        }
        catch (e_4_1) { e_4 = { error: e_4_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_4) throw e_4.error; }
        }
        this._dataSource.data = data;
    };
    NpUiDataGridComponent.prototype._removeAllSorting = function () {
        var e_5, _a;
        try {
            for (var _b = __values(this._columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                element.sortDirection = null;
            }
        }
        catch (e_5_1) { e_5 = { error: e_5_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_5) throw e_5.error; }
        }
        this._sortColumnList = [];
    };
    NpUiDataGridComponent.prototype._removeSortingFromColumn = function (column) {
        var e_6, _a, e_7, _b;
        column.sortDirection = null;
        var list = [];
        try {
            for (var _c = __values(this._sortColumnList), _d = _c.next(); !_d.done; _d = _c.next()) {
                var element = _d.value;
                if (element.dataField !== column.dataField) {
                    list.push(element);
                }
            }
        }
        catch (e_6_1) { e_6 = { error: e_6_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_6) throw e_6.error; }
        }
        this._sortColumnList = list;
        if (!this.isServerOperations) {
            this._resetDataSource();
            this._filterDataSource();
            try {
                for (var _e = __values(this._sortColumnList), _f = _e.next(); !_f.done; _f = _e.next()) {
                    var element = _f.value;
                    this._dataSource.data = this.utilityService.custSort(this._dataSource.data, element.dataField, element.sortDirection);
                }
            }
            catch (e_7_1) { e_7 = { error: e_7_1 }; }
            finally {
                try {
                    if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
                }
                finally { if (e_7) throw e_7.error; }
            }
        }
        this._getCurrentViewData(1);
    };
    NpUiDataGridComponent.prototype._resetDataSource = function () {
        this._dataSource.data = this.dataSource.getValue().data;
        this._total = this._dataSource.data.length;
    };
    NpUiDataGridComponent.prototype._onFilter = function (column, isForceFilter) {
        var e_8, _a;
        if (isForceFilter === void 0) { isForceFilter = false; }
        if (column.filterOperator && column.filterOperator === FilterTypes.Reset) {
            column.filterOperator = undefined;
            column.filterValue = undefined;
            isForceFilter = true;
        }
        if (!isForceFilter && (column.filterValue === undefined || column.filterValue === null || column.filterValue.length === 0
            || column.filterOperator === undefined || column.filterOperator === null)) {
            return;
        }
        var currentFilterList = [];
        try {
            for (var _b = __values(this._columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                if (element.filterOperator === undefined || element.filterOperator === null
                    || element.filterValue === undefined || element.filterValue === null || element.filterValue.toString().length === 0) {
                    continue;
                }
                else {
                    currentFilterList.push({ dataField: element.dataField, filterOperator: element.filterOperator, filterValue: element.filterValue, dataType: element.dataType });
                }
            }
        }
        catch (e_8_1) { e_8 = { error: e_8_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_8) throw e_8.error; }
        }
        this._filterColumnList = currentFilterList;
        this._selectedRowKeys = [];
        this._isAllSelected = false;
        this._openRowKeys = [];
        if (!this.isServerOperations) {
            this._filterDataSource();
            this._sortDataSource();
        }
        this._getCurrentViewData(1);
    };
    NpUiDataGridComponent.prototype._filterDataSource = function () {
        var filterdData = this.filterService.filterData(this._filterColumnList, this.dataSource.getValue().data);
        this._dataSource.data = filterdData;
        this._total = filterdData.length;
    };
    NpUiDataGridComponent.prototype._removeAllFilters = function () {
        var e_9, _a;
        try {
            for (var _b = __values(this._columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                element.filterOperator = null;
                element.filterValue = null;
            }
        }
        catch (e_9_1) { e_9 = { error: e_9_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_9) throw e_9.error; }
        }
        this._filterColumnList = [];
    };
    NpUiDataGridComponent.prototype._onClickToggleMasterChild = function (keyValue) {
        if (this.expandRowOnClick === true) {
            return;
        }
        this._toggleMasterChild(keyValue);
    };
    NpUiDataGridComponent.prototype._toggleMasterChild = function (keyValue) {
        var idx = this._openRowKeys.indexOf(keyValue);
        if (idx === -1) {
            if (this.singleRowExpand) {
                this._openRowKeys = [keyValue];
            }
            else {
                this._openRowKeys.push(keyValue);
            }
        }
        else {
            this._openRowKeys.splice(idx, 1);
        }
    };
    NpUiDataGridComponent.prototype._onClickSelectAll = function (event) {
        if (this.singleRowSelectEnable) {
            return;
        }
        if (event.target.checked) {
            this._selectAll();
        }
        else {
            this._deSelectAll();
        }
    };
    NpUiDataGridComponent.prototype._deSelectAll = function () {
        var selectedRows = this._selectedRowKeys;
        this._selectedRowKeys = [];
        this._isAllSelected = false;
        if (this.onDeselect != undefined) {
            var event = { data: selectedRows };
            this.onDeselect.emit(event);
        }
    };
    NpUiDataGridComponent.prototype._selectAll = function () {
        var e_10, _a, e_11, _b;
        var key = this._key;
        if (this.isServerOperations) {
            var selectedKeys = [];
            try {
                for (var _c = __values(this._currentViewData), _d = _c.next(); !_d.done; _d = _c.next()) {
                    var element = _d.value;
                    selectedKeys.push(element[key]);
                }
            }
            catch (e_10_1) { e_10 = { error: e_10_1 }; }
            finally {
                try {
                    if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
                }
                finally { if (e_10) throw e_10.error; }
            }
        }
        else {
            var selectedKeys = [];
            try {
                for (var _e = __values(this._dataSource.data), _f = _e.next(); !_f.done; _f = _e.next()) {
                    var element = _f.value;
                    selectedKeys.push(element[key]);
                }
            }
            catch (e_11_1) { e_11 = { error: e_11_1 }; }
            finally {
                try {
                    if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
                }
                finally { if (e_11) throw e_11.error; }
            }
        }
        this._selectedRowKeys = selectedKeys;
        this._isAllSelected = true;
        if (this.onSelect != undefined) {
            var event = { data: selectedKeys };
            this.onSelect.emit(event);
        }
    };
    NpUiDataGridComponent.prototype._onClickSelectRow = function (keyValue, event) {
        if (this.selectRowOnClick === true) {
            return;
        }
        this._selectRow(keyValue, event);
    };
    NpUiDataGridComponent.prototype._selectRow = function (keyValue, event) {
        if (this.singleRowSelectEnable) {
            this._selectedRowKeys = [];
            if (event.target.checked) {
                this._selectedRowKeys.push(keyValue);
            }
        }
        else {
            if (event.target.checked) {
                this._selectedRowKeys.push(keyValue);
            }
            else {
                var idx = this._selectedRowKeys.indexOf(keyValue);
                this._selectedRowKeys.splice(idx, 1);
            }
        }
        if (event.target.checked) {
            if (this.onSelect != undefined) {
                event.data = keyValue;
                this.onSelect.emit(event);
            }
        }
        else {
            this._isAllSelected = false;
            if (this.onDeselect != undefined) {
                event.data = keyValue;
                this.onDeselect.emit(event);
            }
        }
    };
    NpUiDataGridComponent.prototype._isSelected = function (keyValue) {
        return this._selectedRowKeys.indexOf(keyValue) > -1;
    };
    NpUiDataGridComponent.prototype._isOpenChild = function (keyValue) {
        return this._openRowKeys.indexOf(keyValue) > -1;
    };
    NpUiDataGridComponent.prototype._rowClick = function (event, data) {
        if (this.masterDetailTemplate && this.expandRowOnClick) {
            this._toggleMasterChild(data[this._key]);
        }
        if ((this.singleRowSelectEnable || this.multiRowSelectEnable) && this.selectRowOnClick) {
            if (this._isSelected(data[this._key])) {
                this._selectRow(data[this._key], { target: { checked: false } });
            }
            else {
                this._selectRow(data[this._key], { target: { checked: true } });
            }
        }
        if (this.onRowClick) {
            event.data = data;
            this.onRowClick.emit(event);
        }
    };
    ;
    NpUiDataGridComponent.prototype._onColumnChoosing = function (col) {
        col.visible = !col.visible;
        this._setVisibleColumns();
    };
    NpUiDataGridComponent.prototype._toggleColumnChooser = function () {
        this._isOpenColumnChooser = !this._isOpenColumnChooser;
    };
    NpUiDataGridComponent.prototype._dropColumn = function (event) {
        this.showLoader();
        moveItemInArray(this._columns, event.previousIndex, event.currentIndex);
        this._setVisibleColumns();
        this.hideLoader();
    };
    /**
     * get selected row keys array
     */
    NpUiDataGridComponent.prototype.getSelectedRowKeys = function () {
        return this._selectedRowKeys;
    };
    /**
     * reset all
     */
    NpUiDataGridComponent.prototype.reset = function () {
        this._setColumns();
        this._filterColumnList = [];
        this._sortColumnList = [];
        this._selectedRowKeys = [];
        this._openRowKeys = [];
        this._isAllSelected = false;
        this._isOpenColumnChooser = false;
        this._currentStateName = "";
        this._pager = this.pagerService.getPager(0, 1, this.pageSize);
        if (this.isServerOperations) {
            this._getCurrentViewData(1);
        }
        else {
            this._resetDataSource();
            this._getCurrentViewData(1);
        }
    };
    /**
     * select all rows
     */
    NpUiDataGridComponent.prototype.selectAll = function () {
        this._selectAll();
    };
    /**
     * de select all rows
     */
    NpUiDataGridComponent.prototype.deSelectAll = function () {
        this._deSelectAll();
    };
    /**
     * show loader
     */
    NpUiDataGridComponent.prototype.showLoader = function () {
        this._showLoader = true;
    };
    /**
     * hide loader
     */
    NpUiDataGridComponent.prototype.hideLoader = function () {
        this._showLoader = false;
    };
    /**
     * hide column by index
     * @param idx index number of column
     */
    NpUiDataGridComponent.prototype.hideColumnByIndex = function (idx) {
        this._columns[idx].visible = false;
        this._setVisibleColumns();
    };
    /**
     * show column by index
     * @param idx index number of column
     */
    NpUiDataGridComponent.prototype.showColumnByIndex = function (idx) {
        this._columns[idx].visible = true;
        this._setVisibleColumns();
    };
    /**
     * hide column by data field
     * @param dataField dataField value of column
     */
    NpUiDataGridComponent.prototype.hideColumnByDataField = function (dataField) {
        var e_12, _a;
        try {
            for (var _b = __values(this._columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                if (element.dataField === dataField) {
                    element.visible = false;
                }
            }
        }
        catch (e_12_1) { e_12 = { error: e_12_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_12) throw e_12.error; }
        }
        this._setVisibleColumns();
    };
    /**
     * show column by data field
     * @param dataField dataField value of column
     */
    NpUiDataGridComponent.prototype.showColumnByDataField = function (dataField) {
        var e_13, _a;
        try {
            for (var _b = __values(this._columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                if (element.dataField === dataField) {
                    element.visible = true;
                }
            }
        }
        catch (e_13_1) { e_13 = { error: e_13_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_13) throw e_13.error; }
        }
        this._setVisibleColumns();
    };
    /**
     * go to page
     * @param pageNumber page number
     */
    NpUiDataGridComponent.prototype.goToPage = function (pageNumber) {
        this._getCurrentViewData(pageNumber);
    };
    /**
     * sort by column
     * @param dataField dataField value of column
     * @param direction desc | asc
     */
    NpUiDataGridComponent.prototype.sortByColumn = function (dataField, direction) {
        var sortColumn = this.utilityService.custFind(this._columns, function (element) { return element.dataField === dataField; });
        sortColumn.sortDirection = direction;
        this._onSort(sortColumn);
    };
    /**
     * filter by column
     * @param dataField dataField value of column
     * @param keyword search keyword
     * @param type FilterTypes
     */
    NpUiDataGridComponent.prototype.filterByColumn = function (dataField, keyword, type) {
        var filterColumn = this.utilityService.custFind(this._columns, function (element) { return element.dataField === dataField; });
        filterColumn.filterString = keyword;
        filterColumn.filterType = type;
        this._onFilter(filterColumn, true);
    };
    /**
     * get total row count
     */
    NpUiDataGridComponent.prototype.getTotalRows = function () {
        return this._pager.totalItems;
    };
    /**
     * get current page number
     */
    NpUiDataGridComponent.prototype.getCurrentPageNumber = function () {
        return this._pager.currentPage;
    };
    /**
     * get page size
     */
    NpUiDataGridComponent.prototype.getPageSize = function () {
        return this.pageSize;
    };
    /**
     * get total pages number
     */
    NpUiDataGridComponent.prototype.getTotalPages = function () {
        return this._pager.totalPages;
    };
    /**
     * close all childs
     */
    NpUiDataGridComponent.prototype.closeAllChild = function () {
        this._openRowKeys = [];
    };
    /**
     * get filter column list
     */
    NpUiDataGridComponent.prototype.getFilterColumns = function () {
        return this._filterColumnList;
    };
    /**
     * get sort column list
     */
    NpUiDataGridComponent.prototype.getSortColumns = function () {
        return this._sortColumnList;
    };
    /**
     * get column list
     */
    NpUiDataGridComponent.prototype.getColumns = function () {
        return this._getColumnsArray();
    };
    /**
     * set column list
     * @param columns
     */
    NpUiDataGridComponent.prototype.setColumns = function (columns) {
        var e_14, _a, e_15, _b;
        this._columns = columns;
        var currentFilterColumnList = [];
        try {
            for (var _c = __values(this._columns), _d = _c.next(); !_d.done; _d = _c.next()) {
                var element = _d.value;
                if (element.filterOperator && element.filterValue && element.filterValue.toString().length > 0) {
                    currentFilterColumnList.push({ dataField: element.dataField, filterOperator: element.filterOperator, filterValue: element.filterValue, dataType: element.dataType });
                }
            }
        }
        catch (e_14_1) { e_14 = { error: e_14_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_14) throw e_14.error; }
        }
        this._filterColumnList = currentFilterColumnList;
        var currentSortColumnList = [];
        try {
            for (var _e = __values(this._columns), _f = _e.next(); !_f.done; _f = _e.next()) {
                var element = _f.value;
                if (element.sortEnable && element.sortDirection) {
                    currentSortColumnList.push({ dataField: element.dataField, sortDirection: element.sortDirection });
                }
            }
        }
        catch (e_15_1) { e_15 = { error: e_15_1 }; }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
            }
            finally { if (e_15) throw e_15.error; }
        }
        this._sortColumnList = currentSortColumnList;
        if (!this.isServerOperations) {
            this._filterDataSource();
            this._sortDataSource();
        }
        this._getCurrentViewData(1);
        this._setVisibleColumns();
        this, this._selectedRowKeys = [];
        this._openRowKeys = [];
    };
    NpUiDataGridComponent.prototype._saveState = function () {
        var e_16, _a;
        var columns = this._getColumnsArray();
        var currentStateName = this._currentStateName;
        try {
            for (var _b = __values(this._stateList), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                if (element.name === currentStateName) {
                    element.columns = columns;
                    alert("Saved successfully.");
                }
            }
        }
        catch (e_16_1) { e_16 = { error: e_16_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_16) throw e_16.error; }
        }
        if (this.onStatesUpdate) {
            this.onStatesUpdate.emit();
        }
    };
    NpUiDataGridComponent.prototype._addState = function () {
        var name = prompt("Please enter name", "");
        if (name === undefined || name === null) {
            return;
        }
        if (name.trim().length === 0) {
            alert("Name is required.");
            return;
        }
        name = name.trim();
        var state = this._stateList.filter(function (element) { if (element.name === name) {
            return element;
        } });
        if (state && state.length > 0) {
            alert("Name already exist.");
            return;
        }
        var columns = this._getColumnsArray();
        this._stateList.push(new State(name, columns));
        this._currentStateName = name;
        if (this.onStatesUpdate) {
            this.onStatesUpdate.emit();
        }
    };
    NpUiDataGridComponent.prototype._deleteState = function () {
        var e_17, _a;
        var currentStateName = this._currentStateName;
        var list = [];
        try {
            for (var _b = __values(this._stateList), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                if (element.name != currentStateName) {
                    list.push(element);
                }
            }
        }
        catch (e_17_1) { e_17 = { error: e_17_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_17) throw e_17.error; }
        }
        this._stateList = list;
        if (this._stateList.length > 0) {
            this._currentStateName = this._stateList[0].name;
        }
        else {
            this._currentStateName = "";
        }
        this._loadState();
        if (this.onStatesUpdate) {
            this.onStatesUpdate.emit();
        }
    };
    NpUiDataGridComponent.prototype._loadState = function () {
        var currentStateName = this._currentStateName;
        if (currentStateName === "") {
            this.reset();
            return;
        }
        var state = this._stateList.filter(function (element) { if (element.name === currentStateName) {
            return element;
        } });
        if (state && state.length > 0) {
            this.setColumns(state[0].columns);
        }
    };
    NpUiDataGridComponent.prototype._getColumnsArray = function () {
        var e_18, _a;
        var result = [];
        try {
            for (var _b = __values(this._columns), _c = _b.next(); !_c.done; _c = _b.next()) {
                var element = _c.value;
                result.push(new Column(element));
            }
        }
        catch (e_18_1) { e_18 = { error: e_18_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_18) throw e_18.error; }
        }
        return result;
    };
    /**
     * get state list
     */
    NpUiDataGridComponent.prototype.getAllState = function () {
        return this._stateList;
    };
    /**
     * set state list
     * @param states state array
     */
    NpUiDataGridComponent.prototype.setAllState = function (states) {
        this._stateList = states;
    };
    /**
     * refresh current view data only
     */
    NpUiDataGridComponent.prototype.refresh = function () {
        this._onRefresh();
    };
    NpUiDataGridComponent.prototype._onRefresh = function () {
        this._getCurrentViewData(this._pager.currentPage);
    };
    NpUiDataGridComponent.prototype._onResetColumns = function () {
        this.reset();
    };
    NpUiDataGridComponent.prototype._resizeColumn = function ($event, column) {
        var currentWidth = column.width;
        if (isNaN(currentWidth)) {
            currentWidth = $event.source.element.nativeElement.parentElement.offsetWidth;
        }
        column.width = (isNaN(currentWidth) ? 0 : currentWidth) + $event.distance.x;
        $event.source.reset();
    };
    NpUiDataGridComponent.prototype._exportAsCSV = function () {
        this.showLoader();
        if (this.isServerOperations) {
            var loadOpt = new LoadOptions();
            if (this.isODataOperations) {
                loadOpt.odataQuery = this.oDataService.buildQuery(0, 0, this._sortColumnList, this._filterColumnList, "allpages");
                loadOpt.isAllPages = true;
            }
            else {
                loadOpt.pageNumber = 1;
                loadOpt.pageSize = this._pager.totalItems;
                loadOpt.sortColumns = this._sortColumnList;
                loadOpt.filterColumns = this._filterColumnList;
                loadOpt.isAllPages = true;
            }
            this.onLoadData.emit(loadOpt);
        }
        else {
            this.fileService.downloadCSVFile(this._dataSource.data, this._visibleColumns);
            this.hideLoader();
        }
    };
    /**
     * Remove all sortings
     */
    NpUiDataGridComponent.prototype.removeAllSortings = function () {
        this._removeAllSorting();
        this._getCurrentViewData(1);
    };
    /**
     * Remove all filters
     */
    NpUiDataGridComponent.prototype.removeAllFilters = function () {
        this._removeAllFilters();
        this._getCurrentViewData(1);
    };
    NpUiDataGridComponent.prototype._getHeight = function () {
        return this.height - (this.title && this.title.length > 0 ? 26 : 0) - (this.showToolBar ? 39 : 0) - 39;
    };
    NpUiDataGridComponent.prototype._showAllColumns = function () {
        this._columns.forEach(function (element) {
            element.visible = true;
        });
        this._setVisibleColumns();
    };
    NpUiDataGridComponent.prototype._clearColumnSearch = function () {
        this._searchColumnsKeyword = null;
    };
    NpUiDataGridComponent.ctorParameters = function () { return [
        { type: NpPagerService },
        { type: NpFilterService },
        { type: NpUtilityService },
        { type: NpODataService },
        { type: NpFileService }
    ]; };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], NpUiDataGridComponent.prototype, "columns", void 0);
    __decorate([
        Input(),
        __metadata("design:type", BehaviorSubject)
    ], NpUiDataGridComponent.prototype, "dataSource", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], NpUiDataGridComponent.prototype, "height", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], NpUiDataGridComponent.prototype, "width", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "multiColumnSortEnable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", TemplateRef)
    ], NpUiDataGridComponent.prototype, "masterDetailTemplate", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "singleRowExpand", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "expandRowOnClick", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "stickyHeader", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "singleRowSelectEnable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "multiRowSelectEnable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "selectRowOnClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NpUiDataGridComponent.prototype, "onSelect", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NpUiDataGridComponent.prototype, "onDeselect", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], NpUiDataGridComponent.prototype, "key", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NpUiDataGridComponent.prototype, "onRowClick", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], NpUiDataGridComponent.prototype, "tableId", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "showColumnChooser", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], NpUiDataGridComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "enableStateStoring", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NpUiDataGridComponent.prototype, "onStatesUpdate", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], NpUiDataGridComponent.prototype, "noDataMessage", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "showFilters", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NpUiDataGridComponent.prototype, "onInit", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NpUiDataGridComponent.prototype, "onAfterInit", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "showSummary", void 0);
    __decorate([
        Input(),
        __metadata("design:type", TemplateRef)
    ], NpUiDataGridComponent.prototype, "summaryTemplate", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "allowColumnResize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "allowColumnReorder", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], NpUiDataGridComponent.prototype, "onLoadData", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "isServerOperations", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "isODataOperations", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "allowExportToCSV", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], NpUiDataGridComponent.prototype, "showToolBar", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], NpUiDataGridComponent.prototype, "pageSize", void 0);
    NpUiDataGridComponent = __decorate([
        Component({
            selector: 'np-ui-data-grid',
            template: "<div class=\"np-dg-component\" [style.max-height.px]=\"height\" [style.max-width.px]=\"width\" [id]=\"_tableId\">\r\n    <div [ngClass]=\"{'np-dg-loading': _showLoader}\">\r\n        <div *ngIf=\"_showLoader\" class=\"np-dg-loader\"></div>\r\n    </div>\r\n    <ng-container *ngIf=\"title\">\r\n        <div class=\"np-dg-title np-dg-background\">\r\n            <label [innerHTML]=\"title\"></label>\r\n        </div>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"showToolBar\">\r\n        <div class=\"np-dg-toolbar np-dg-background\">\r\n            <ng-container *ngIf=\"showColumnChooser\">\r\n                <div class=\"np-dg-toolbar-item\">\r\n                    <a title=\"Column chooser\" class=\"np-dg-icon-btn-lg\" (click)=\"_toggleColumnChooser()\">\r\n                        <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                            <path fill=\"currentcolor\" d=\"M4 5v13h17V5H4zm10 2v9h-3V7h3zM6 7h3v9H6V7zm13 9h-3V7h3v9z\" />\r\n                        </svg>\r\n                    </a>\r\n                    <div class=\"np-dg-col-chooser np-dg-background\"\r\n                        [ngClass]=\"{'np-dg-col-chooser-open':_isOpenColumnChooser}\">\r\n                        <div class=\"np-dg-col-chooser-actions\">\r\n                            <a class=\"np-dg-icon-btn\" title=\"Show all columns\" (click)=\"_showAllColumns()\">\r\n                                <svg class=\"np-dg-icon\" viewBox=\"0 0 24 24\">\r\n                                    <path d=\"M0 0h24v24H0z\" fill=\"none\" />\r\n                                    <path fill=\"currentcolor\"\r\n                                        d=\"M12 4.5C7 4.5 2.73 7.61 1 12c1.73 4.39 6 7.5 11 7.5s9.27-3.11 11-7.5c-1.73-4.39-6-7.5-11-7.5zM12 17c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5zm0-8c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3z\" />\r\n                                </svg>\r\n                            </a>\r\n                            <a class=\"np-dg-icon-btn\" title=\"Reset all\" (click)=\"_onResetColumns()\">\r\n                                <svg class=\"np-dg-icon\" viewBox=\"0 0 24 24\">\r\n                                    <path fill=\"currentcolor\"\r\n                                        d=\"M12 6v3l4-4-4-4v3c-4.42 0-8 3.58-8 8 0 1.57.46 3.03 1.24 4.26L6.7 14.8c-.45-.83-.7-1.79-.7-2.8 0-3.31 2.69-6 6-6zm6.76 1.74L17.3 9.2c.44.84.7 1.79.7 2.8 0 3.31-2.69 6-6 6v-3l-4 4 4 4v-3c4.42 0 8-3.58 8-8 0-1.57-.46-3.03-1.24-4.26z\" />\r\n                                    <path d=\"M0 0h24v24H0z\" fill=\"none\" />\r\n                                </svg>\r\n                            </a>\r\n                            <a class=\"np-dg-icon-btn\" title=\"Close\" (click)=\"_isOpenColumnChooser = false\">\r\n                                <svg class=\"np-dg-icon\" viewBox=\"0 0 24 24\">\r\n                                    <path fill=\"currentcolor\"\r\n                                        d=\"M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z\" />\r\n                                    <path d=\"M0 0h24v24H0z\" fill=\"none\" />\r\n                                </svg>\r\n                            </a>\r\n                        </div>\r\n                        <div class=\"np-dg-search-columns\">\r\n                            <input type=\"text\" placeholder=\"Search columns...\" class=\"np-dg-control\"\r\n                                [(ngModel)]=\"_searchColumnsKeyword\">\r\n                            <a class=\"np-dg-icon-btn\" title=\"Clear\" (click)=\"_clearColumnSearch()\">\r\n                                <svg class=\"np-dg-icon\" viewBox=\"0 0 24 24\">\r\n                                    <path fill=\"currentcolor\"\r\n                                        d=\"M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z\" />\r\n                                    <path d=\"M0 0h24v24H0z\" fill=\"none\" />\r\n                                </svg>\r\n                            </a>\r\n                        </div>\r\n                        <div class=\"np-dg-columns\" cdkDropList [cdkDropListDisabled]=\"!allowColumnReorder\"\r\n                            (cdkDropListDropped)=\"_dropColumn($event)\">\r\n                            <div *ngFor=\"let column of _columns | searchColumnsPipe : _searchColumnsKeyword\"\r\n                                class=\"np-dg-columns-item\" cdkDrag cdkDragLockAxis=\"y\" cdkDragBoundary=\".np-dg-columns\"\r\n                                [cdkDragDisabled]=\"column.stickyColumnLeft || column.stickyColumnRight\">\r\n                                <label>\r\n                                    <input type=\"checkbox\" [checked]=\"column.visible\" class=\"np-dg-checkbox\"\r\n                                        (change)=\"_onColumnChoosing(column)\">{{column.caption}}\r\n                                </label>\r\n                                <div class=\"np-dg-col-drag-placeholder\" *cdkDragPlaceholder></div>\r\n                                <div *ngIf=\"allowColumnReorder\" class=\"np-dg-col-drag-handle\" cdkDragHandle>\r\n                                    <svg class=\"np-dg-icon\" viewBox=\"0 0 24 24\">\r\n                                        <path fill=\"currentcolor\"\r\n                                            d=\"M10 9h4V6h3l-5-5-5 5h3v3zm-1 1H6V7l-5 5 5 5v-3h3v-4zm14 2l-5-5v3h-3v4h3v3l5-5zm-9 3h-4v3H7l5 5 5-5h-3v-3z\" />\r\n                                    </svg>\r\n                                </div>\r\n                            </div>\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n            </ng-container>\r\n            <ng-container *ngIf=\"_isFilterAvailable\">\r\n                <div class=\"np-dg-toolbar-item\">\r\n                    <a class=\"np-dg-icon-btn-lg\" title=\"Toggle filters\" (click)=\"showFilters = !showFilters\">\r\n                        <svg *ngIf=\"!showFilters\" class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                            <path fill=\"currentcolor\"\r\n                                d=\"M15,19.88C15.04,20.18 14.94,20.5 14.71,20.71C14.32,21.1 13.69,21.1 13.3,20.71L9.29,16.7C9.06,16.47 8.96,16.16 9,15.87V10.75L4.21,4.62C3.87,4.19 3.95,3.56 4.38,3.22C4.57,3.08 4.78,3 5,3V3H19V3C19.22,3 19.43,3.08 19.62,3.22C20.05,3.56 20.13,4.19 19.79,4.62L15,10.75V19.88M7.04,5L11,10.06V15.58L13,17.58V10.05L16.96,5H7.04Z\" />\r\n                        </svg>\r\n                        <svg *ngIf=\"showFilters\" class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                            <path fill=\"currentcolor\"\r\n                                d=\"M14.73,20.83L17.58,18L14.73,15.17L16.15,13.76L19,16.57L21.8,13.76L23.22,15.17L20.41,18L23.22,20.83L21.8,22.24L19,19.4L16.15,22.24L14.73,20.83M13,19.88C13.04,20.18 12.94,20.5 12.71,20.71C12.32,21.1 11.69,21.1 11.3,20.71L7.29,16.7C7.06,16.47 6.96,16.16 7,15.87V10.75L2.21,4.62C1.87,4.19 1.95,3.56 2.38,3.22C2.57,3.08 2.78,3 3,3V3H17V3C17.22,3 17.43,3.08 17.62,3.22C18.05,3.56 18.13,4.19 17.79,4.62L13,10.75V19.88M5.04,5L9,10.06V15.58L11,17.58V10.05L14.96,5H5.04Z\" />\r\n                        </svg>\r\n                    </a>\r\n                </div>\r\n            </ng-container>\r\n            <ng-container *ngIf=\"allowExportToCSV\">\r\n                <div class=\"np-dg-toolbar-item\">\r\n                    <a title=\"Export to CSV\" class=\"np-dg-icon-btn-lg\" (click)=\"_exportAsCSV()\">\r\n                        <svg viewBox=\"0 0 24 24\" class=\"np-dg-icon-lg\">\r\n                            <path fill=\"currentcolor\"\r\n                                d=\"M14 2H6c-1.1 0-1.99.9-1.99 2L4 20c0 1.1.89 2 1.99 2H18c1.1 0 2-.9 2-2V8l-6-6zM6 20V4h7v5h5v11H6z\" />\r\n                        </svg>\r\n                    </a>\r\n                </div>\r\n            </ng-container>\r\n            <ng-container *ngIf=\"enableStateStoring\">\r\n                <div class=\"np-dg-toolbar-item float-right\">\r\n                    <div class=\"np-dg-state-manager\">\r\n                        <select class=\"np-dg-control np-dg-state-manager-item\" [(ngModel)]=\"_currentStateName\"\r\n                            (change)=\"_loadState()\">\r\n                            <option value=\"\">Select...</option>\r\n                            <option *ngFor=\"let state of _stateList\" [ngValue]=\"state.name\">{{state.name}}</option>\r\n                        </select>\r\n                        <a *ngIf=\"_currentStateName.length > 0\" class=\"np-dg-icon-btn-lg np-dg-state-manager-item\"\r\n                            title=\"Save state\" (click)=\"_saveState()\">\r\n                            <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                                <path fill=\"currentcolor\"\r\n                                    d=\"M17 3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.1 0 2-.9 2-2V7l-4-4zm2 16H5V5h11.17L19 7.83V19zm-7-7c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3zM6 6h9v4H6z\" />\r\n                            </svg>\r\n                        </a>\r\n                        <a *ngIf=\"_currentStateName.length > 0\" class=\"np-dg-icon-btn-lg np-dg-state-manager-item\"\r\n                            title=\"Delete state\" (click)=\"_deleteState()\">\r\n                            <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                                <path fill=\"currentcolor\"\r\n                                    d=\"M14.12 10.47L12 12.59l-2.13-2.12-1.41 1.41L10.59 14l-2.12 2.12 1.41 1.41L12 15.41l2.12 2.12 1.41-1.41L13.41 14l2.12-2.12zM15.5 4l-1-1h-5l-1 1H5v2h14V4zM6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zM8 9h8v10H8V9z\" />\r\n                            </svg>\r\n                        </a>\r\n                        <a class=\"np-dg-icon-btn-lg np-dg-state-manager-item\" title=\"Add state\"\r\n                            (click)=\"_addState()\">\r\n                            <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                                <path fill=\"currentcolor\"\r\n                                    d=\"M19 3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm0 16H5V5h14v14zm-8-2h2v-4h4v-2h-4V7h-2v4H7v2h4z\" />\r\n                            </svg>\r\n                        </a>\r\n                    </div>\r\n                </div>\r\n            </ng-container>\r\n        </div>\r\n    </ng-container>\r\n    <div class=\"np-dg-container\" [style.max-height.px]=\"_getHeight()\">\r\n        <div class=\"np-dg-table-header np-dg-background\" [ngClass]=\"{'np-dg-sticky-header':stickyHeader}\">\r\n            <table>\r\n                <colgroup>\r\n                    <col style=\"width: 30px;\" *ngIf=\"_enableMasterChild\">\r\n                    <col style=\"width: 30px;\" *ngIf=\"singleRowSelectEnable || multiRowSelectEnable\">\r\n                    <col *ngFor=\"let column of _visibleColumns\" [style.width.px]=\"column.width\">\r\n                </colgroup>\r\n                <thead>\r\n                    <tr class=\"np-dg-header-row\">\r\n                        <th *ngIf=\"_enableMasterChild\"></th>\r\n                        <th *ngIf=\"singleRowSelectEnable || multiRowSelectEnable\">\r\n                            <input *ngIf=\"multiRowSelectEnable\" type=\"checkbox\" class=\"np-dg-checkbox\"\r\n                                title=\"Select/Unselect all\" [(ngModel)]=\"_isAllSelected\"\r\n                                (change)=\"_onClickSelectAll($event)\">\r\n                        </th>\r\n                        <th *ngFor=\"let column of _visibleColumns; let k = index\"\r\n                            [ngClass]=\"{'hidden': column.visible === false,'np-dg-sticky-left':column.stickyColumnLeft,'np-dg-sticky-right':column.stickyColumnRight}\">\r\n                            <span [innerHTML]=\"column.caption\" (click)=\"_onSort(column)\"\r\n                                [ngClass]=\"{'np-dg-cursor-pointer': column.sortEnable}\"></span>\r\n                            <div *ngIf=\"allowColumnResize\" class=\"np-dg-col-resize-handle float-right\" cdkDrag\r\n                                cdkDragLockAxis=\"x\" (cdkDragEnded)=\"_resizeColumn($event, column)\"></div>\r\n                            <a *ngIf=\"column.sortEnable != null\" class=\"np-dg-icon-btn float-right\"\r\n                                (click)=\"_onSort(column)\">\r\n                                <svg *ngIf=\"column.sortDirection === _sortDirections.Ascending\" class=\"np-dg-icon\"\r\n                                    viewBox=\"0 0 24 24\">\r\n                                    <path fill=\"currentcolor\"\r\n                                        d=\"M20 12l-1.41-1.41L13 16.17V4h-2v12.17l-5.58-5.59L4 12l8 8 8-8z\" /></svg>\r\n                                <svg *ngIf=\"column.sortDirection === _sortDirections.Descending\" class=\"np-dg-icon\"\r\n                                    viewBox=\"0 0 24 24\">\r\n                                    <path fill=\"currentcolor\"\r\n                                        d=\"M4 12l1.41 1.41L11 7.83V20h2V7.83l5.58 5.59L20 12l-8-8-8 8z\" />\r\n                                </svg>\r\n                                <svg *ngIf=\"!column.sortDirection\" class=\"np-dg-icon np-dg-sort-enable\"\r\n                                    viewBox=\"0 0 24 24\">\r\n                                    <path d=\"M9 3L5 6.99h3V14h2V6.99h3L9 3zm7 14.01V10h-2v7.01h-3L15 21l4-3.99h-3z\"\r\n                                        fill=\"currentcolor\" />\r\n                                    <path d=\"M0 0h24v24H0z\" fill=\"none\" />\r\n                                </svg>\r\n                            </a>\r\n                        </th>\r\n                    </tr>\r\n                </thead>\r\n            </table>\r\n        </div>\r\n        <div class=\"np-dg-table-body\">\r\n            <table>\r\n                <colgroup>\r\n                    <col style=\"width: 30px;\" *ngIf=\"_enableMasterChild\">\r\n                    <col style=\"width: 30px;\" *ngIf=\"singleRowSelectEnable || multiRowSelectEnable\">\r\n                    <col *ngFor=\"let column of _visibleColumns\" [style.width.px]=\"column.width\">\r\n                </colgroup>\r\n                <ng-container *ngIf=\"_isFilterAvailable && showFilters\">\r\n                    <thead>\r\n                        <tr class=\"np-dg-header-row\">\r\n                            <th *ngIf=\"_enableMasterChild\"></th>\r\n                            <th *ngIf=\"singleRowSelectEnable || multiRowSelectEnable\"></th>\r\n                            <th *ngFor=\"let column of _visibleColumns; let l = index\"\r\n                                [ngClass]=\"{'hidden': column.visible === false, 'np-dg-sticky-left':column.stickyColumnLeft, 'np-dg-sticky-right':column.stickyColumnRight}\">\r\n                                <ng-container *ngIf=\"column.filterEnable\">\r\n                                    <div class=\"np-dg-filter-operator\">\r\n                                        <select class=\"np-dg-control\" [(ngModel)]=\"column.filterOperator\"\r\n                                            (change)=\"_onFilter(column, false)\">\r\n                                            <option [value]=\"undefined\" disabled hidden>Select...</option>\r\n                                            <option\r\n                                                *ngFor=\"let fOperator of _filtersList | filterTypesPipe: column.dataType\"\r\n                                                [value]=\"fOperator.name\">{{fOperator.text}}\r\n                                            </option>\r\n                                            <option value=\"Reset\" [disabled]=\"column.filterOperator === undefined\">Reset\r\n                                            </option>\r\n                                        </select>\r\n                                    </div>\r\n                                    <div>\r\n                                        <input *ngIf=\"column.dataType === _dataTypes.String\" type=\"text\"\r\n                                            class=\"np-dg-control\" [(ngModel)]=\"column.filterValue\"\r\n                                            (change)=\"_onFilter(column, false)\" placeholder=\"Search...\">\r\n                                        <input *ngIf=\"column.dataType === _dataTypes.Number\" type=\"number\"\r\n                                            class=\"np-dg-control\" [(ngModel)]=\"column.filterValue\"\r\n                                            (change)=\"_onFilter(column, false)\" placeholder=\"Search...\">\r\n                                        <input *ngIf=\"column.dataType === _dataTypes.Date\" type=\"date\"\r\n                                            class=\"np-dg-control\" [(ngModel)]=\"column.filterValue\"\r\n                                            (change)=\"_onFilter(column, false)\" placeholder=\"Search...\">\r\n                                        <select *ngIf=\"column.dataType === _dataTypes.Boolean\" class=\"np-dg-control\"\r\n                                            [(ngModel)]=\"column.filterValue\" (change)=\"_onFilter(column, false)\">\r\n                                            <option [value]=\"undefined\" disabled hidden>Select...</option>\r\n                                            <option [value]=\"true\">True</option>\r\n                                            <option [value]=\"false\">False</option>\r\n                                        </select>\r\n                                    </div>\r\n                                </ng-container>\r\n                            </th>\r\n                        </tr>\r\n                    </thead>\r\n                </ng-container>\r\n                <tbody>\r\n                    <ng-container *ngFor=\"let data of _currentViewData; let  i = index\">\r\n                        <tr id=\"row_{{i}}\" (click)=\"_rowClick($event,data)\" class=\"np-dg-body-row\"\r\n                            [ngClass]=\"{'np-dg-row-selected': _isSelected(data[_key])}\">\r\n                            <ng-container *ngIf=\"_enableMasterChild\">\r\n                                <td>\r\n                                    <a class=\"np-dg-icon-btn\" (click)=\"_onClickToggleMasterChild(data[_key])\">\r\n                                        <svg *ngIf=\"!_isOpenChild(data[_key])\" class=\"np-dg-icon\" viewBox=\"0 0 24 24\">\r\n                                            <path d=\"M19 13h-6v6h-2v-6H5v-2h6V5h2v6h6v2z\" fill=\"currentcolor\" />\r\n                                            <path d=\"M0 0h24v24H0z\" fill=\"none\" /></svg>\r\n                                        <svg *ngIf=\"_isOpenChild(data[_key])\" class=\"np-dg-icon\" viewBox=\"0 0 24 24\">\r\n                                            <path d=\"M19 13H5v-2h14v2z\" fill=\"currentcolor\" />\r\n                                            <path d=\"M0 0h24v24H0z\" fill=\"none\" /></svg>\r\n                                    </a>\r\n                                </td>\r\n                            </ng-container>\r\n                            <ng-container *ngIf=\"singleRowSelectEnable || multiRowSelectEnable\">\r\n                                <td>\r\n                                    <input type=\"checkbox\" class=\"np-dg-checkbox\" [checked]=\"_isSelected(data[_key])\"\r\n                                        (change)=\"_onClickSelectRow(data[_key],$event)\">\r\n                                </td>\r\n                            </ng-container>\r\n                            <td *ngFor=\"let column of _visibleColumns; let j = index\"\r\n                                (click)=\"_onCellClick($event, column, data)\" [class]=\"column.styleClass\"\r\n                                [ngClass]=\"{'hidden': column.visible === false, 'txt-right' : column.rightAlignText,'np-dg-sticky-left': column.stickyColumnLeft,'np-dg-sticky-right':column.stickyColumnRight}\">\r\n                                <ng-container *ngIf=\"!column.cellTemplate; else customTemplate\">\r\n                                    {{data[column.dataField]}}\r\n                                </ng-container>\r\n                                <ng-template #customTemplate [ngTemplateOutlet]=\"column.cellTemplate\"\r\n                                    [ngTemplateOutletContext]=\"{ row: data }\">\r\n                                </ng-template>\r\n                            </td>\r\n                        </tr>\r\n                        <ng-container *ngIf=\"_enableMasterChild && _isOpenChild(data[_key])\">\r\n                            <tr id=\"row_{{i}}_child\" class=\"np-dg-child-row\">\r\n                                <td\r\n                                    [attr.colspan]=\"_visibleColumns.length + (singleRowSelectEnable || multiRowSelectEnable ? 1 : 0) + 1\">\r\n                                    <ng-container *ngTemplateOutlet=\"masterDetailTemplate;context:{ row: data }\">\r\n                                    </ng-container>\r\n                                </td>\r\n                            </tr>\r\n                        </ng-container>\r\n                    </ng-container>\r\n                </tbody>\r\n            </table>\r\n        </div>\r\n        <div class=\"np-dg-table-footer\">\r\n            <ng-container *ngIf=\"_currentViewData && _currentViewData.length === 0 && !_showLoader\">\r\n                <div class=\"np-dg-no-data-message\">\r\n                    {{noDataMessage}}\r\n                </div>\r\n            </ng-container>\r\n            <ng-container *ngIf=\"showSummary\">\r\n                <div class=\"np-dg-table-summary np-dg-background\">\r\n                    <ng-container *ngTemplateOutlet=\"summaryTemplate;context:{ summary: _summaryData }\">\r\n                    </ng-container>\r\n                </div>\r\n            </ng-container>\r\n        </div>\r\n    </div>\r\n    <ng-container *ngIf=\"_pager && _pager.pages && _pager.pages.length > 0\">\r\n        <div class=\"np-dg-pagination np-dg-background\">\r\n            <div class=\"np-dg-pagination-item\">\r\n                <a class=\"np-dg-icon-btn-lg\" title=\"First page\"\r\n                    [ngClass]=\"{'np-dg-disabled':_pager.currentPage === 1}\" (click)=\"_getCurrentViewData(1)\">\r\n                    <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                        <path fill=\"currentcolor\" d=\"M18.41 16.59L13.82 12l4.59-4.59L17 6l-6 6 6 6zM6 6h2v12H6z\"></path>\r\n                    </svg>\r\n                </a>\r\n            </div>\r\n            <div class=\"np-dg-pagination-item\">\r\n                <a class=\"np-dg-icon-btn-lg\" title=\"Prev page\"\r\n                    [ngClass]=\"{'np-dg-disabled':_pager.currentPage === 1}\"\r\n                    (click)=\"_getCurrentViewData(_pager.currentPage - 1)\">\r\n                    <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                        <path fill=\"currentcolor\" d=\"M15.41 7.41L14 6l-6 6 6 6 1.41-1.41L10.83 12z\"></path>\r\n                    </svg>\r\n                </a>\r\n            </div>\r\n            <div class=\"np-dg-pagination-item\">\r\n                <input type=\"number\" class=\"np-dg-control \" [(ngModel)]=\"_pager.currentPage\"\r\n                    (change)=\"_getCurrentViewData(_pager.currentPage)\"> / {{_pager.totalPages}}\r\n            </div>\r\n            <div class=\"np-dg-pagination-item\">\r\n                <a title=\"Next page\" class=\"np-dg-icon-btn-lg\"\r\n                    [ngClass]=\"{'np-dg-disabled':_pager.currentPage === _pager.totalPages}\"\r\n                    (click)=\"_getCurrentViewData(_pager.currentPage + 1)\">\r\n                    <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                        <path fill=\"currentcolor\" d=\"M10 6L8.59 7.41 13.17 12l-4.58 4.59L10 18l6-6z\"></path>\r\n                    </svg>\r\n                </a>\r\n            </div>\r\n            <div class=\"np-dg-pagination-item\">\r\n                <a title=\"Last page\" class=\"np-dg-icon-btn-lg\"\r\n                    [ngClass]=\"{'np-dg-disabled':_pager.currentPage === _pager.totalPages}\"\r\n                    (click)=\"_getCurrentViewData(_pager.totalPages)\">\r\n                    <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                        <path fill=\"currentcolor\" d=\"M5.59 7.41L10.18 12l-4.59 4.59L7 18l6-6-6-6zM16 6h2v12h-2z\"></path>\r\n                    </svg>\r\n                </a>\r\n            </div>\r\n            <div class=\"np-dg-pagination-item float-right\">\r\n                <a *ngIf=\"isServerOperations\" class=\"np-dg-icon-btn-lg\" title=\"Refresh\" (click)=\"_onRefresh()\">\r\n                    <svg class=\"np-dg-icon-lg\" viewBox=\"0 0 24 24\">\r\n                        <path fill=\"currentcolor\"\r\n                            d=\"M17.65 6.35C16.2 4.9 14.21 4 12 4c-4.42 0-7.99 3.58-7.99 8s3.57 8 7.99 8c3.73 0 6.84-2.55 7.73-6h-2.08c-.82 2.33-3.04 4-5.65 4-3.31 0-6-2.69-6-6s2.69-6 6-6c1.66 0 3.14.69 4.22 1.78L13 11h7V4l-2.35 2.35z\" />\r\n                        <path d=\"M0 0h24v24H0z\" fill=\"none\" />\r\n                    </svg>\r\n                </a>\r\n            </div>\r\n            <div class=\"np-dg-pagination-item float-right\">\r\n                <input type=\"number\" class=\"np-dg-control\" [(ngModel)]=\"pageSize\" (change)=\"_onPageSizeChange()\">\r\n                per page / {{_pager.startIndex >= 0 ? _pager.startIndex + 1 : 0}} - {{_pager.endIndex + 1}} of\r\n                {{_pager.totalItems}}\r\n            </div>\r\n        </div>\r\n    </ng-container>\r\n</div>",
            encapsulation: ViewEncapsulation.None,
            changeDetection: ChangeDetectionStrategy.Default,
            styles: [".np-dg-component{border:1px solid #000;box-sizing:border-box;position:relative}.np-dg-title{height:26px;border-bottom:1px solid #000;box-sizing:border-box;width:100%;padding:3px 5px}.np-dg-toolbar{height:39px;border-bottom:1px solid #000;box-sizing:border-box;width:100%;padding:3px 5px}.np-dg-toolbar-item{margin:2px;display:inline-block;vertical-align:middle}.np-dg-icon-btn-lg{box-sizing:border-box;border:1px solid #000;height:28px;width:28px;padding:1px;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:block}.np-dg-icon-btn{box-sizing:border-box;border:1px solid #000;height:20px;width:20px;padding:1px;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:block}.np-dg-icon-lg{height:24px;width:24px}.np-dg-icon{height:16px;width:16px}.np-dg-col-chooser{max-height:300px;width:250px;display:none;border:1px solid #000;box-sizing:border-box;position:absolute;padding:5px;z-index:2;overflow:auto}.np-dg-col-chooser-open{display:block}.np-dg-col-chooser-actions{width:100%;height:24px;display:-webkit-box;display:flex;-webkit-box-pack:end;justify-content:flex-end}.np-dg-col-chooser-actions .np-dg-icon-btn{margin:2px}.np-dg-container .np-dg-icon-btn:hover{background-color:transparent!important}.np-dg-columns-item.cdk-drag-disabled .np-dg-col-drag-handle{display:none}.np-dg-state-manager-item{margin:0 2px;display:inline-block;vertical-align:middle}.np-dg-columns{border-top:1px solid #000;border-left:1px solid #000;border-right:1px solid #000;box-sizing:border-box;border-bottom:none}.np-dg-columns-item{border-bottom:1px solid #000;box-sizing:border-box;height:25px;padding:2px}.np-dg-col-drag-placeholder{background-color:#fafad2;height:25px}.np-dg-col-drag-handle{float:right;padding:2px;cursor:move}.np-dg-columns-item.cdk-drag-preview{border:1px solid #000;box-sizing:border-box}.np-dg-cursor-pointer{cursor:pointer}.np-dg-container{overflow-x:auto}.np-dg-table-body table,.np-dg-table-header table{table-layout:fixed;border-collapse:separate;border-spacing:0;width:100%}.np-dg-table-header th{text-align:left;vertical-align:middle;padding:0 0 0 5px;margin:0;border-right:1px solid #000;border-bottom:1px solid #000;box-sizing:border-box;line-height:25px;font-weight:700}.np-dg-table-body th{text-align:left;vertical-align:middle;padding:3px 5px;margin:0;border-right:1px solid #000;border-bottom:1px solid #000;box-sizing:border-box}.np-dg-filter-operator{margin-bottom:3px}.np-dg-table-body td{padding:0 5px;margin:0;border-right:1px solid #000;border-bottom:1px solid #000;box-sizing:border-box;line-height:24px;background-color:#fff;overflow:hidden}.np-dg-table-body td:last-child,.np-dg-table-body th:last-child,.np-dg-table-header th:last-child{border-right:none}.np-dg-table-body tr:last-child td{border-bottom:none}.np-dg-table-body .np-dg-icon-btn,.np-dg-table-header .np-dg-icon-btn{border:none}.np-dg-pagination{height:39px;border-top:1px solid #000;box-sizing:border-box;width:100%;padding:3px 5px}.np-dg-pagination-item{display:inline-block;vertical-align:middle;margin:2px}.np-dg-control{border:1px solid #000;box-sizing:border-box;padding:2px;height:28px}.np-dg-state-manager .np-dg-control{max-width:150px}.np-dg-pagination .np-dg-control{width:100px}.np-dg-table-body thead .np-dg-control{width:100%}.np-dg-disabled{opacity:.5;pointer-events:none}.np-dg-col-resize-handle{width:7px;height:25px;cursor:col-resize}.np-dg-col-resize-handle.cdk-drag-dragging,.np-dg-col-resize-handle:hover{background-color:#fafad2}.np-dg-loading{position:absolute;top:0;left:0;width:100%;height:100%;opacity:.5;background-color:#00000066;z-index:3}.np-dg-loader{position:absolute;top:calc(50% - 25px);left:calc(50% - 25px);border:8px solid #fff;border-radius:50%;border-top:8px solid #add8e6;box-sizing:border-box;width:50px;height:50px;-webkit-animation:2s linear infinite spin;animation:2s linear infinite spin;z-index:4}@-webkit-keyframes spin{0%{-webkit-transform:rotate(0);transform:rotate(0)}100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes spin{0%{-webkit-transform:rotate(0);transform:rotate(0)}100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}.np-dg-sticky-header{position:-webkit-sticky;position:sticky;top:0;z-index:1}.np-dg-sticky-left{position:-webkit-sticky;position:sticky;left:0}.np-dg-sticky-right{position:-webkit-sticky;position:sticky;right:0;border-left:1px solid #000;box-sizing:border-box}.np-dg-table-summary{border-top:1px solid #000;box-sizing:border-box;padding:3px 5px}.np-dg-table-footer{position:-webkit-sticky;position:sticky;left:0;bottom:0}.np-dg-no-data-message{padding:0 5px;text-align:center}.np-dg-checkbox{cursor:pointer;height:15px;width:15px;vertical-align:middle}.np-dg-sort-enable{display:none}.np-dg-table-header th:hover .np-dg-sort-enable{display:block}.np-dg-background,.np-dg-body-row:hover td,.np-dg-columns-item,.np-dg-control,.np-dg-header-row th{background-color:#f0f8ff}.np-dg-row-selected td,.np-dg-row-selected:hover td{background-color:#add8e6}.np-dg-child-row td{padding:5px 10px;background-color:#fafad2}.np-dg-icon-btn-lg:hover,.np-dg-icon-btn:hover{background-color:#add8e6}.np-dg-search-columns{padding:5px;display:-webkit-box;display:flex;-webkit-box-align:center;align-items:center;justify-content:space-around}.float-right{float:right}.txt-center{text-align:center}.txt-right{text-align:right}"]
        }),
        __metadata("design:paramtypes", [NpPagerService,
            NpFilterService,
            NpUtilityService,
            NpODataService,
            NpFileService])
    ], NpUiDataGridComponent);
    return NpUiDataGridComponent;
}());

var NpFilterTypesPipe = /** @class */ (function () {
    function NpFilterTypesPipe() {
    }
    NpFilterTypesPipe.prototype.transform = function (filterList, args) {
        return filterList.filter(function (filterType) { return filterType.forDataType === args; });
    };
    NpFilterTypesPipe = __decorate([
        Pipe({
            name: 'filterTypesPipe'
        }),
        Injectable()
    ], NpFilterTypesPipe);
    return NpFilterTypesPipe;
}());

var NpSearchColumnsPipe = /** @class */ (function () {
    function NpSearchColumnsPipe() {
    }
    NpSearchColumnsPipe.prototype.transform = function (filterList, args) {
        if (args) {
            var result = filterList.filter(function (column) {
                return column.caption && column.caption.toLowerCase().startsWith(args, 0);
            });
            return result;
        }
        return filterList;
    };
    NpSearchColumnsPipe = __decorate([
        Pipe({
            name: 'searchColumnsPipe'
        }),
        Injectable()
    ], NpSearchColumnsPipe);
    return NpSearchColumnsPipe;
}());

var NpUiDataGridModule = /** @class */ (function () {
    function NpUiDataGridModule() {
    }
    NpUiDataGridModule = __decorate([
        NgModule({
            declarations: [
                NpUiDataGridComponent,
                NpFilterTypesPipe,
                NpSearchColumnsPipe
            ],
            imports: [
                CommonModule,
                FormsModule,
                DragDropModule
            ],
            exports: [
                NpUiDataGridComponent
            ],
            providers: [
                NpPagerService,
                NpFilterService,
                NpUtilityService,
                NpODataService,
                NpFileService
            ]
        })
    ], NpUiDataGridModule);
    return NpUiDataGridModule;
}());

/*
 * Public API Surface of np-ui-data-grid
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Column, Constants, DataSource, DataTypes, FilterTypes, LoadOptions, NpUiDataGridComponent, NpUiDataGridModule, SortDirections, State, NpPagerService as ɵa, NpFilterService as ɵb, NpUtilityService as ɵc, NpODataService as ɵd, NpFileService as ɵe, NpFilterTypesPipe as ɵf, NpSearchColumnsPipe as ɵg };
//# sourceMappingURL=np-ui-data-grid.js.map
