import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { AfterViewInit, EventEmitter, OnDestroy, OnInit, TemplateRef } from '@angular/core';
import { BehaviorSubject, Subscription } from 'rxjs';
import { Column } from './models/column.model';
import { DataTypes, FilterTypes, SortDirections } from './models/constants';
import { DataSource } from './models/data-source.model';
import { LoadOptions } from './models/load-options.model';
import { Pager } from './models/pager.model';
import { State } from './models/state.model';
import { NpFileService } from './services/np-ui-file.service';
import { NpFilterService } from './services/np-ui-filter.service';
import { NpODataService } from './services/np-ui-odata.service';
import { NpPagerService } from './services/np-ui-pager.service';
import { NpUtilityService } from './services/np-ui-utility.service';
export declare class NpUiDataGridComponent implements OnInit, AfterViewInit, OnDestroy {
    private pagerService;
    private filterService;
    private utilityService;
    private oDataService;
    private fileService;
    columns: Column[];
    _columns: Column[];
    dataSource: BehaviorSubject<DataSource>;
    _dataSource: DataSource;
    _subscription: Subscription;
    /**current view data */
    _currentViewData: any[];
    _pager: Pager;
    _total: number;
    _filtersList: any[];
    height: number;
    width: number;
    multiColumnSortEnable: boolean;
    _sortColumnList: any[];
    _filterColumnList: any[];
    _isFilterAvailable: boolean;
    _enableMasterChild: boolean;
    masterDetailTemplate: TemplateRef<any>;
    singleRowExpand: boolean;
    expandRowOnClick: boolean;
    _openRowKeys: any[];
    stickyHeader: boolean;
    _showLoader: boolean;
    singleRowSelectEnable: boolean;
    multiRowSelectEnable: boolean;
    selectRowOnClick: boolean;
    _selectedRowKeys: any[];
    _isAllSelected: boolean;
    onSelect: EventEmitter<any>;
    onDeselect: EventEmitter<any>;
    key: string;
    _key: string;
    onRowClick: EventEmitter<any>;
    _dataTypes: typeof DataTypes;
    _sortDirections: typeof SortDirections;
    tableId: string;
    _tableId: string;
    showColumnChooser: boolean;
    _isOpenColumnChooser: boolean;
    _visibleColumns: any[];
    title: string;
    enableStateStoring: boolean;
    _stateList: State[];
    _currentStateName: string;
    onStatesUpdate: EventEmitter<any>;
    noDataMessage: string;
    showFilters: boolean;
    onInit: EventEmitter<any>;
    onAfterInit: EventEmitter<any>;
    showSummary: boolean;
    summaryTemplate: TemplateRef<any>;
    _summaryData: any;
    allowColumnResize: boolean;
    allowColumnReorder: boolean;
    onLoadData: EventEmitter<LoadOptions>;
    isServerOperations: boolean;
    isODataOperations: boolean;
    allowExportToCSV: boolean;
    showToolBar: boolean;
    pageSize: number;
    _searchColumnsKeyword: string;
    constructor(pagerService: NpPagerService, filterService: NpFilterService, utilityService: NpUtilityService, oDataService: NpODataService, fileService: NpFileService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnChanges(changes: any): void;
    private subscribeDataSource;
    ngOnDestroy(): void;
    _getCurrentViewData(currentPageNumber: number): void;
    _setColumns(): void;
    _setVisibleColumns(): void;
    _onPageSizeChange(): void;
    _onCellClick($event: any, column: Column, data: any): void;
    _onSort(column: Column): void;
    _sortDataSource(): void;
    _removeAllSorting(): void;
    _removeSortingFromColumn(column: Column): void;
    _resetDataSource(): void;
    _onFilter(column: Column, isForceFilter?: boolean): void;
    _filterDataSource(): void;
    _removeAllFilters(): void;
    _onClickToggleMasterChild(keyValue: any): void;
    _toggleMasterChild(keyValue: any): void;
    _onClickSelectAll(event: any): void;
    _deSelectAll(): void;
    _selectAll(): void;
    _onClickSelectRow(keyValue: any, event: any): void;
    _selectRow(keyValue: any, event: any): void;
    _isSelected(keyValue: any): boolean;
    _isOpenChild(keyValue: any): boolean;
    _rowClick(event: any, data: any): void;
    _onColumnChoosing(col: Column): void;
    _toggleColumnChooser(): void;
    _dropColumn(event: CdkDragDrop<string[]>): void;
    /**
     * get selected row keys array
     */
    getSelectedRowKeys(): any[];
    /**
     * reset all
     */
    reset(): void;
    /**
     * select all rows
     */
    selectAll(): void;
    /**
     * de select all rows
     */
    deSelectAll(): void;
    /**
     * show loader
     */
    showLoader(): void;
    /**
     * hide loader
     */
    hideLoader(): void;
    /**
     * hide column by index
     * @param idx index number of column
     */
    hideColumnByIndex(idx: number): void;
    /**
     * show column by index
     * @param idx index number of column
     */
    showColumnByIndex(idx: number): void;
    /**
     * hide column by data field
     * @param dataField dataField value of column
     */
    hideColumnByDataField(dataField: string): void;
    /**
     * show column by data field
     * @param dataField dataField value of column
     */
    showColumnByDataField(dataField: string): void;
    /**
     * go to page
     * @param pageNumber page number
     */
    goToPage(pageNumber: number): void;
    /**
     * sort by column
     * @param dataField dataField value of column
     * @param direction desc | asc
     */
    sortByColumn(dataField: string, direction: SortDirections): void;
    /**
     * filter by column
     * @param dataField dataField value of column
     * @param keyword search keyword
     * @param type FilterTypes
     */
    filterByColumn(dataField: string, keyword: string, type: FilterTypes): void;
    /**
     * get total row count
     */
    getTotalRows(): number;
    /**
     * get current page number
     */
    getCurrentPageNumber(): number;
    /**
     * get page size
     */
    getPageSize(): number;
    /**
     * get total pages number
     */
    getTotalPages(): number;
    /**
     * close all childs
     */
    closeAllChild(): void;
    /**
     * get filter column list
     */
    getFilterColumns(): any[];
    /**
     * get sort column list
     */
    getSortColumns(): any[];
    /**
     * get column list
     */
    getColumns(): any[];
    /**
     * set column list
     * @param columns
     */
    setColumns(columns: Column[]): void;
    _saveState(): void;
    _addState(): void;
    _deleteState(): void;
    _loadState(): void;
    private _getColumnsArray;
    /**
     * get state list
     */
    getAllState(): State[];
    /**
     * set state list
     * @param states state array
     */
    setAllState(states: State[]): void;
    /**
     * refresh current view data only
     */
    refresh(): void;
    _onRefresh(): void;
    _onResetColumns(): void;
    _resizeColumn($event: any, column: Column): void;
    _exportAsCSV(): void;
    /**
     * Remove all sortings
     */
    removeAllSortings(): void;
    /**
     * Remove all filters
     */
    removeAllFilters(): void;
    _getHeight(): number;
    _showAllColumns(): void;
    _clearColumnSearch(): void;
}
